Documentation
¶
Overview ¶
Package v1 is a generated protocol buffer package.
It is generated from these files:
k8s.io/api/networking/v1/generated.proto
It has these top-level messages:
IPBlock NetworkPolicy NetworkPolicyEgressRule NetworkPolicyIngressRule NetworkPolicyList NetworkPolicyPeer NetworkPolicyPort NetworkPolicySpec
Index ¶
- Variables
- type IPBlock
- func (*IPBlock) Descriptor() ([]byte, []int)
- func (m *IPBlock) GetCidr() string
- func (m *IPBlock) GetExcept() []string
- func (m *IPBlock) Marshal() (dAtA []byte, err error)
- func (m *IPBlock) MarshalTo(dAtA []byte) (int, error)
- func (*IPBlock) ProtoMessage()
- func (m *IPBlock) Reset()
- func (m *IPBlock) Size() (n int)
- func (m *IPBlock) String() string
- func (m *IPBlock) Unmarshal(dAtA []byte) error
- type NetworkPolicy
- func (*NetworkPolicy) Descriptor() ([]byte, []int)
- func (m *NetworkPolicy) GetMetadata() *k8s_io_apimachinery_pkg_apis_meta_v1.ObjectMeta
- func (m *NetworkPolicy) GetSpec() *NetworkPolicySpec
- func (m *NetworkPolicy) Marshal() (dAtA []byte, err error)
- func (m *NetworkPolicy) MarshalTo(dAtA []byte) (int, error)
- func (*NetworkPolicy) ProtoMessage()
- func (m *NetworkPolicy) Reset()
- func (m *NetworkPolicy) Size() (n int)
- func (m *NetworkPolicy) String() string
- func (m *NetworkPolicy) Unmarshal(dAtA []byte) error
- type NetworkPolicyEgressRule
- func (*NetworkPolicyEgressRule) Descriptor() ([]byte, []int)
- func (m *NetworkPolicyEgressRule) GetPorts() []*NetworkPolicyPort
- func (m *NetworkPolicyEgressRule) GetTo() []*NetworkPolicyPeer
- func (m *NetworkPolicyEgressRule) Marshal() (dAtA []byte, err error)
- func (m *NetworkPolicyEgressRule) MarshalTo(dAtA []byte) (int, error)
- func (*NetworkPolicyEgressRule) ProtoMessage()
- func (m *NetworkPolicyEgressRule) Reset()
- func (m *NetworkPolicyEgressRule) Size() (n int)
- func (m *NetworkPolicyEgressRule) String() string
- func (m *NetworkPolicyEgressRule) Unmarshal(dAtA []byte) error
- type NetworkPolicyIngressRule
- func (*NetworkPolicyIngressRule) Descriptor() ([]byte, []int)
- func (m *NetworkPolicyIngressRule) GetFrom() []*NetworkPolicyPeer
- func (m *NetworkPolicyIngressRule) GetPorts() []*NetworkPolicyPort
- func (m *NetworkPolicyIngressRule) Marshal() (dAtA []byte, err error)
- func (m *NetworkPolicyIngressRule) MarshalTo(dAtA []byte) (int, error)
- func (*NetworkPolicyIngressRule) ProtoMessage()
- func (m *NetworkPolicyIngressRule) Reset()
- func (m *NetworkPolicyIngressRule) Size() (n int)
- func (m *NetworkPolicyIngressRule) String() string
- func (m *NetworkPolicyIngressRule) Unmarshal(dAtA []byte) error
- type NetworkPolicyList
- func (*NetworkPolicyList) Descriptor() ([]byte, []int)
- func (m *NetworkPolicyList) GetItems() []*NetworkPolicy
- func (m *NetworkPolicyList) GetMetadata() *k8s_io_apimachinery_pkg_apis_meta_v1.ListMeta
- func (m *NetworkPolicyList) Marshal() (dAtA []byte, err error)
- func (m *NetworkPolicyList) MarshalTo(dAtA []byte) (int, error)
- func (*NetworkPolicyList) ProtoMessage()
- func (m *NetworkPolicyList) Reset()
- func (m *NetworkPolicyList) Size() (n int)
- func (m *NetworkPolicyList) String() string
- func (m *NetworkPolicyList) Unmarshal(dAtA []byte) error
- type NetworkPolicyPeer
- func (*NetworkPolicyPeer) Descriptor() ([]byte, []int)
- func (m *NetworkPolicyPeer) GetIpBlock() *IPBlock
- func (m *NetworkPolicyPeer) GetNamespaceSelector() *k8s_io_apimachinery_pkg_apis_meta_v1.LabelSelector
- func (m *NetworkPolicyPeer) GetPodSelector() *k8s_io_apimachinery_pkg_apis_meta_v1.LabelSelector
- func (m *NetworkPolicyPeer) Marshal() (dAtA []byte, err error)
- func (m *NetworkPolicyPeer) MarshalTo(dAtA []byte) (int, error)
- func (*NetworkPolicyPeer) ProtoMessage()
- func (m *NetworkPolicyPeer) Reset()
- func (m *NetworkPolicyPeer) Size() (n int)
- func (m *NetworkPolicyPeer) String() string
- func (m *NetworkPolicyPeer) Unmarshal(dAtA []byte) error
- type NetworkPolicyPort
- func (*NetworkPolicyPort) Descriptor() ([]byte, []int)
- func (m *NetworkPolicyPort) GetPort() *k8s_io_apimachinery_pkg_util_intstr.IntOrString
- func (m *NetworkPolicyPort) GetProtocol() string
- func (m *NetworkPolicyPort) Marshal() (dAtA []byte, err error)
- func (m *NetworkPolicyPort) MarshalTo(dAtA []byte) (int, error)
- func (*NetworkPolicyPort) ProtoMessage()
- func (m *NetworkPolicyPort) Reset()
- func (m *NetworkPolicyPort) Size() (n int)
- func (m *NetworkPolicyPort) String() string
- func (m *NetworkPolicyPort) Unmarshal(dAtA []byte) error
- type NetworkPolicySpec
- func (*NetworkPolicySpec) Descriptor() ([]byte, []int)
- func (m *NetworkPolicySpec) GetEgress() []*NetworkPolicyEgressRule
- func (m *NetworkPolicySpec) GetIngress() []*NetworkPolicyIngressRule
- func (m *NetworkPolicySpec) GetPodSelector() *k8s_io_apimachinery_pkg_apis_meta_v1.LabelSelector
- func (m *NetworkPolicySpec) GetPolicyTypes() []string
- func (m *NetworkPolicySpec) Marshal() (dAtA []byte, err error)
- func (m *NetworkPolicySpec) MarshalTo(dAtA []byte) (int, error)
- func (*NetworkPolicySpec) ProtoMessage()
- func (m *NetworkPolicySpec) Reset()
- func (m *NetworkPolicySpec) Size() (n int)
- func (m *NetworkPolicySpec) String() string
- func (m *NetworkPolicySpec) Unmarshal(dAtA []byte) error
Constants ¶
This section is empty.
Variables ¶
var ( ErrInvalidLengthGenerated = fmt.Errorf("proto: negative length found during unmarshaling") ErrIntOverflowGenerated = fmt.Errorf("proto: integer overflow") )
Functions ¶
This section is empty.
Types ¶
type IPBlock ¶
type IPBlock struct {
// CIDR is a string representing the IP Block
// Valid examples are "192.168.1.1/24"
Cidr *string `protobuf:"bytes,1,opt,name=cidr" json:"cidr,omitempty"`
// Except is a slice of CIDRs that should not be included within an IP Block
// Valid examples are "192.168.1.1/24"
// Except values will be rejected if they are outside the CIDR range
// +optional
Except []string `protobuf:"bytes,2,rep,name=except" json:"except,omitempty"`
XXX_unrecognized []byte `json:"-"`
}
IPBlock describes a particular CIDR (Ex. "192.168.1.1/24") that is allowed to the pods matched by a NetworkPolicySpec's podSelector. The except entry describes CIDRs that should not be included within this rule.
func (*IPBlock) Descriptor ¶
func (*IPBlock) ProtoMessage ¶
func (*IPBlock) ProtoMessage()
type NetworkPolicy ¶
type NetworkPolicy struct {
// Standard object's metadata.
// More info: https://git.k8s.io/community/contributors/devel/api-conventions.md#metadata
// +optional
Metadata *k8s_io_apimachinery_pkg_apis_meta_v1.ObjectMeta `protobuf:"bytes,1,opt,name=metadata" json:"metadata,omitempty"`
// Specification of the desired behavior for this NetworkPolicy.
// +optional
Spec *NetworkPolicySpec `protobuf:"bytes,2,opt,name=spec" json:"spec,omitempty"`
XXX_unrecognized []byte `json:"-"`
}
NetworkPolicy describes what network traffic is allowed for a set of Pods
func (*NetworkPolicy) Descriptor ¶
func (*NetworkPolicy) Descriptor() ([]byte, []int)
func (*NetworkPolicy) GetMetadata ¶
func (m *NetworkPolicy) GetMetadata() *k8s_io_apimachinery_pkg_apis_meta_v1.ObjectMeta
func (*NetworkPolicy) GetSpec ¶
func (m *NetworkPolicy) GetSpec() *NetworkPolicySpec
func (*NetworkPolicy) Marshal ¶
func (m *NetworkPolicy) Marshal() (dAtA []byte, err error)
func (*NetworkPolicy) ProtoMessage ¶
func (*NetworkPolicy) ProtoMessage()
func (*NetworkPolicy) Reset ¶
func (m *NetworkPolicy) Reset()
func (*NetworkPolicy) Size ¶
func (m *NetworkPolicy) Size() (n int)
func (*NetworkPolicy) String ¶
func (m *NetworkPolicy) String() string
func (*NetworkPolicy) Unmarshal ¶
func (m *NetworkPolicy) Unmarshal(dAtA []byte) error
type NetworkPolicyEgressRule ¶
type NetworkPolicyEgressRule struct {
// List of destination ports for outgoing traffic.
// Each item in this list is combined using a logical OR. If this field is
// empty or missing, this rule matches all ports (traffic not restricted by port).
// If this field is present and contains at least one item, then this rule allows
// traffic only if the traffic matches at least one port in the list.
// +optional
Ports []*NetworkPolicyPort `protobuf:"bytes,1,rep,name=ports" json:"ports,omitempty"`
// List of destinations for outgoing traffic of pods selected for this rule.
// Items in this list are combined using a logical OR operation. If this field is
// empty or missing, this rule matches all destinations (traffic not restricted by
// destination). If this field is present and contains at least one item, this rule
// allows traffic only if the traffic matches at least one item in the to list.
// +optional
To []*NetworkPolicyPeer `protobuf:"bytes,2,rep,name=to" json:"to,omitempty"`
XXX_unrecognized []byte `json:"-"`
}
NetworkPolicyEgressRule describes a particular set of traffic that is allowed out of pods matched by a NetworkPolicySpec's podSelector. The traffic must match both ports and to. This type is beta-level in 1.8
func (*NetworkPolicyEgressRule) Descriptor ¶
func (*NetworkPolicyEgressRule) Descriptor() ([]byte, []int)
func (*NetworkPolicyEgressRule) GetPorts ¶
func (m *NetworkPolicyEgressRule) GetPorts() []*NetworkPolicyPort
func (*NetworkPolicyEgressRule) GetTo ¶
func (m *NetworkPolicyEgressRule) GetTo() []*NetworkPolicyPeer
func (*NetworkPolicyEgressRule) Marshal ¶
func (m *NetworkPolicyEgressRule) Marshal() (dAtA []byte, err error)
func (*NetworkPolicyEgressRule) MarshalTo ¶
func (m *NetworkPolicyEgressRule) MarshalTo(dAtA []byte) (int, error)
func (*NetworkPolicyEgressRule) ProtoMessage ¶
func (*NetworkPolicyEgressRule) ProtoMessage()
func (*NetworkPolicyEgressRule) Reset ¶
func (m *NetworkPolicyEgressRule) Reset()
func (*NetworkPolicyEgressRule) Size ¶
func (m *NetworkPolicyEgressRule) Size() (n int)
func (*NetworkPolicyEgressRule) String ¶
func (m *NetworkPolicyEgressRule) String() string
func (*NetworkPolicyEgressRule) Unmarshal ¶
func (m *NetworkPolicyEgressRule) Unmarshal(dAtA []byte) error
type NetworkPolicyIngressRule ¶
type NetworkPolicyIngressRule struct {
// List of ports which should be made accessible on the pods selected for this
// rule. Each item in this list is combined using a logical OR. If this field is
// empty or missing, this rule matches all ports (traffic not restricted by port).
// If this field is present and contains at least one item, then this rule allows
// traffic only if the traffic matches at least one port in the list.
// +optional
Ports []*NetworkPolicyPort `protobuf:"bytes,1,rep,name=ports" json:"ports,omitempty"`
// List of sources which should be able to access the pods selected for this rule.
// Items in this list are combined using a logical OR operation. If this field is
// empty or missing, this rule matches all sources (traffic not restricted by
// source). If this field is present and contains at least on item, this rule
// allows traffic only if the traffic matches at least one item in the from list.
// +optional
From []*NetworkPolicyPeer `protobuf:"bytes,2,rep,name=from" json:"from,omitempty"`
XXX_unrecognized []byte `json:"-"`
}
NetworkPolicyIngressRule describes a particular set of traffic that is allowed to the pods matched by a NetworkPolicySpec's podSelector. The traffic must match both ports and from.
func (*NetworkPolicyIngressRule) Descriptor ¶
func (*NetworkPolicyIngressRule) Descriptor() ([]byte, []int)
func (*NetworkPolicyIngressRule) GetFrom ¶
func (m *NetworkPolicyIngressRule) GetFrom() []*NetworkPolicyPeer
func (*NetworkPolicyIngressRule) GetPorts ¶
func (m *NetworkPolicyIngressRule) GetPorts() []*NetworkPolicyPort
func (*NetworkPolicyIngressRule) Marshal ¶
func (m *NetworkPolicyIngressRule) Marshal() (dAtA []byte, err error)
func (*NetworkPolicyIngressRule) MarshalTo ¶
func (m *NetworkPolicyIngressRule) MarshalTo(dAtA []byte) (int, error)
func (*NetworkPolicyIngressRule) ProtoMessage ¶
func (*NetworkPolicyIngressRule) ProtoMessage()
func (*NetworkPolicyIngressRule) Reset ¶
func (m *NetworkPolicyIngressRule) Reset()
func (*NetworkPolicyIngressRule) Size ¶
func (m *NetworkPolicyIngressRule) Size() (n int)
func (*NetworkPolicyIngressRule) String ¶
func (m *NetworkPolicyIngressRule) String() string
func (*NetworkPolicyIngressRule) Unmarshal ¶
func (m *NetworkPolicyIngressRule) Unmarshal(dAtA []byte) error
type NetworkPolicyList ¶
type NetworkPolicyList struct {
// Standard list metadata.
// More info: https://git.k8s.io/community/contributors/devel/api-conventions.md#metadata
// +optional
Metadata *k8s_io_apimachinery_pkg_apis_meta_v1.ListMeta `protobuf:"bytes,1,opt,name=metadata" json:"metadata,omitempty"`
// Items is a list of schema objects.
Items []*NetworkPolicy `protobuf:"bytes,2,rep,name=items" json:"items,omitempty"`
XXX_unrecognized []byte `json:"-"`
}
NetworkPolicyList is a list of NetworkPolicy objects.
func (*NetworkPolicyList) Descriptor ¶
func (*NetworkPolicyList) Descriptor() ([]byte, []int)
func (*NetworkPolicyList) GetItems ¶
func (m *NetworkPolicyList) GetItems() []*NetworkPolicy
func (*NetworkPolicyList) GetMetadata ¶
func (m *NetworkPolicyList) GetMetadata() *k8s_io_apimachinery_pkg_apis_meta_v1.ListMeta
func (*NetworkPolicyList) Marshal ¶
func (m *NetworkPolicyList) Marshal() (dAtA []byte, err error)
func (*NetworkPolicyList) MarshalTo ¶
func (m *NetworkPolicyList) MarshalTo(dAtA []byte) (int, error)
func (*NetworkPolicyList) ProtoMessage ¶
func (*NetworkPolicyList) ProtoMessage()
func (*NetworkPolicyList) Reset ¶
func (m *NetworkPolicyList) Reset()
func (*NetworkPolicyList) Size ¶
func (m *NetworkPolicyList) Size() (n int)
func (*NetworkPolicyList) String ¶
func (m *NetworkPolicyList) String() string
func (*NetworkPolicyList) Unmarshal ¶
func (m *NetworkPolicyList) Unmarshal(dAtA []byte) error
type NetworkPolicyPeer ¶
type NetworkPolicyPeer struct {
// This is a label selector which selects Pods in this namespace. This field
// follows standard label selector semantics. If present but empty, this selector
// selects all pods in this namespace.
// +optional
PodSelector *k8s_io_apimachinery_pkg_apis_meta_v1.LabelSelector `protobuf:"bytes,1,opt,name=podSelector" json:"podSelector,omitempty"`
// Selects Namespaces using cluster scoped-labels. This matches all pods in all
// namespaces selected by this label selector. This field follows standard label
// selector semantics. If present but empty, this selector selects all namespaces.
// +optional
NamespaceSelector *k8s_io_apimachinery_pkg_apis_meta_v1.LabelSelector `protobuf:"bytes,2,opt,name=namespaceSelector" json:"namespaceSelector,omitempty"`
// IPBlock defines policy on a particular IPBlock
// +optional
IpBlock *IPBlock `protobuf:"bytes,3,opt,name=ipBlock" json:"ipBlock,omitempty"`
XXX_unrecognized []byte `json:"-"`
}
NetworkPolicyPeer describes a peer to allow traffic from. Exactly one of its fields must be specified.
func (*NetworkPolicyPeer) Descriptor ¶
func (*NetworkPolicyPeer) Descriptor() ([]byte, []int)
func (*NetworkPolicyPeer) GetIpBlock ¶
func (m *NetworkPolicyPeer) GetIpBlock() *IPBlock
func (*NetworkPolicyPeer) GetNamespaceSelector ¶
func (m *NetworkPolicyPeer) GetNamespaceSelector() *k8s_io_apimachinery_pkg_apis_meta_v1.LabelSelector
func (*NetworkPolicyPeer) GetPodSelector ¶
func (m *NetworkPolicyPeer) GetPodSelector() *k8s_io_apimachinery_pkg_apis_meta_v1.LabelSelector
func (*NetworkPolicyPeer) Marshal ¶
func (m *NetworkPolicyPeer) Marshal() (dAtA []byte, err error)
func (*NetworkPolicyPeer) MarshalTo ¶
func (m *NetworkPolicyPeer) MarshalTo(dAtA []byte) (int, error)
func (*NetworkPolicyPeer) ProtoMessage ¶
func (*NetworkPolicyPeer) ProtoMessage()
func (*NetworkPolicyPeer) Reset ¶
func (m *NetworkPolicyPeer) Reset()
func (*NetworkPolicyPeer) Size ¶
func (m *NetworkPolicyPeer) Size() (n int)
func (*NetworkPolicyPeer) String ¶
func (m *NetworkPolicyPeer) String() string
func (*NetworkPolicyPeer) Unmarshal ¶
func (m *NetworkPolicyPeer) Unmarshal(dAtA []byte) error
type NetworkPolicyPort ¶
type NetworkPolicyPort struct {
// The protocol (TCP or UDP) which traffic must match. If not specified, this
// field defaults to TCP.
// +optional
Protocol *string `protobuf:"bytes,1,opt,name=protocol" json:"protocol,omitempty"`
// The port on the given protocol. This can either be a numerical or named port on
// a pod. If this field is not provided, this matches all port names and numbers.
// +optional
Port *k8s_io_apimachinery_pkg_util_intstr.IntOrString `protobuf:"bytes,2,opt,name=port" json:"port,omitempty"`
XXX_unrecognized []byte `json:"-"`
}
NetworkPolicyPort describes a port to allow traffic on
func (*NetworkPolicyPort) Descriptor ¶
func (*NetworkPolicyPort) Descriptor() ([]byte, []int)
func (*NetworkPolicyPort) GetPort ¶
func (m *NetworkPolicyPort) GetPort() *k8s_io_apimachinery_pkg_util_intstr.IntOrString
func (*NetworkPolicyPort) GetProtocol ¶
func (m *NetworkPolicyPort) GetProtocol() string
func (*NetworkPolicyPort) Marshal ¶
func (m *NetworkPolicyPort) Marshal() (dAtA []byte, err error)
func (*NetworkPolicyPort) MarshalTo ¶
func (m *NetworkPolicyPort) MarshalTo(dAtA []byte) (int, error)
func (*NetworkPolicyPort) ProtoMessage ¶
func (*NetworkPolicyPort) ProtoMessage()
func (*NetworkPolicyPort) Reset ¶
func (m *NetworkPolicyPort) Reset()
func (*NetworkPolicyPort) Size ¶
func (m *NetworkPolicyPort) Size() (n int)
func (*NetworkPolicyPort) String ¶
func (m *NetworkPolicyPort) String() string
func (*NetworkPolicyPort) Unmarshal ¶
func (m *NetworkPolicyPort) Unmarshal(dAtA []byte) error
type NetworkPolicySpec ¶
type NetworkPolicySpec struct {
// Selects the pods to which this NetworkPolicy object applies. The array of
// ingress rules is applied to any pods selected by this field. Multiple network
// policies can select the same set of pods. In this case, the ingress rules for
// each are combined additively. This field is NOT optional and follows standard
// label selector semantics. An empty podSelector matches all pods in this
// namespace.
PodSelector *k8s_io_apimachinery_pkg_apis_meta_v1.LabelSelector `protobuf:"bytes,1,opt,name=podSelector" json:"podSelector,omitempty"`
// List of ingress rules to be applied to the selected pods. Traffic is allowed to
// a pod if there are no NetworkPolicies selecting the pod
// (and cluster policy otherwise allows the traffic), OR if the traffic source is
// the pod's local node, OR if the traffic matches at least one ingress rule
// across all of the NetworkPolicy objects whose podSelector matches the pod. If
// this field is empty then this NetworkPolicy does not allow any traffic (and serves
// solely to ensure that the pods it selects are isolated by default)
// +optional
Ingress []*NetworkPolicyIngressRule `protobuf:"bytes,2,rep,name=ingress" json:"ingress,omitempty"`
// List of egress rules to be applied to the selected pods. Outgoing traffic is
// allowed if there are no NetworkPolicies selecting the pod (and cluster policy
// otherwise allows the traffic), OR if the traffic matches at least one egress rule
// across all of the NetworkPolicy objects whose podSelector matches the pod. If
// this field is empty then this NetworkPolicy limits all outgoing traffic (and serves
// solely to ensure that the pods it selects are isolated by default).
// This field is beta-level in 1.8
// +optional
Egress []*NetworkPolicyEgressRule `protobuf:"bytes,3,rep,name=egress" json:"egress,omitempty"`
// List of rule types that the NetworkPolicy relates to.
// Valid options are Ingress, Egress, or Ingress,Egress.
// If this field is not specified, it will default based on the existence of Ingress or Egress rules;
// policies that contain an Egress section are assumed to affect Egress, and all policies
// (whether or not they contain an Ingress section) are assumed to affect Ingress.
// If you want to write an egress-only policy, you must explicitly specify policyTypes [ "Egress" ].
// Likewise, if you want to write a policy that specifies that no egress is allowed,
// you must specify a policyTypes value that include "Egress" (since such a policy would not include
// an Egress section and would otherwise default to just [ "Ingress" ]).
// This field is beta-level in 1.8
// +optional
PolicyTypes []string `protobuf:"bytes,4,rep,name=policyTypes" json:"policyTypes,omitempty"`
XXX_unrecognized []byte `json:"-"`
}
NetworkPolicySpec provides the specification of a NetworkPolicy
func (*NetworkPolicySpec) Descriptor ¶
func (*NetworkPolicySpec) Descriptor() ([]byte, []int)
func (*NetworkPolicySpec) GetEgress ¶
func (m *NetworkPolicySpec) GetEgress() []*NetworkPolicyEgressRule
func (*NetworkPolicySpec) GetIngress ¶
func (m *NetworkPolicySpec) GetIngress() []*NetworkPolicyIngressRule
func (*NetworkPolicySpec) GetPodSelector ¶
func (m *NetworkPolicySpec) GetPodSelector() *k8s_io_apimachinery_pkg_apis_meta_v1.LabelSelector
func (*NetworkPolicySpec) GetPolicyTypes ¶
func (m *NetworkPolicySpec) GetPolicyTypes() []string
func (*NetworkPolicySpec) Marshal ¶
func (m *NetworkPolicySpec) Marshal() (dAtA []byte, err error)
func (*NetworkPolicySpec) MarshalTo ¶
func (m *NetworkPolicySpec) MarshalTo(dAtA []byte) (int, error)
func (*NetworkPolicySpec) ProtoMessage ¶
func (*NetworkPolicySpec) ProtoMessage()
func (*NetworkPolicySpec) Reset ¶
func (m *NetworkPolicySpec) Reset()
func (*NetworkPolicySpec) Size ¶
func (m *NetworkPolicySpec) Size() (n int)
func (*NetworkPolicySpec) String ¶
func (m *NetworkPolicySpec) String() string
func (*NetworkPolicySpec) Unmarshal ¶
func (m *NetworkPolicySpec) Unmarshal(dAtA []byte) error